This helper function will read in all csv files, remove sensor data, and combine all files into a single dataframe.
tidy_merge(file_list, na = c("", "NA", "unknown"), metadata_only = TRUE)
| file_list | a vector of file paths to be combined |
|---|---|
| na | a vector of values to read in as NA |
| metadata_only | if TRUE (default), subset to only time columns |
a tibble with timestamp and `UTC time` columns